function [out Fout f_ax] = designGaussian(A,T,nLen,n0,fc)
% function [out Fout f_ax] = designGaussian(A,T,nLen,n0,fc)
%
% Design a Gaussian pulse for FDTD simulation:
%       A       - Pulse amplitude
%       T       - Sample period (1/fs)
%       nLen    - Length of pulse (samples)
%       n0      - Time shifting (samples)
%       fc      - Normalized cutoff frequency (0.5=Nyquist)
%
% Returns:
%       out     - Pulse in discrete time domain
%       Fout    - DFT Magnitude of pulse (dB)
%       f_ax    - Frequency axis (normalised) for Fout
%
% Example:
%       [out Fout f_ax] = designGaussian(1,1/44100,1024,50,0.25);
%
% Based on:
% J. Sheaffer, M. van Walstijn, and B. M. Fazenda. 
% "Physical and numerical constraints in source modelling for finite 
%   difference simulation of room acoustics."
%
% Code by Jonathan Sheaffer, University of Salford, March 2013
% contact: jon@jonsh.net
%
sigma=sqrt(2*log(2))/(2*pi*(fc/T));
n=0:nLen-1;
out=A*exp(-T^2*(n-n0).^2/(2*sigma^2));
Fout=20*log10(abs(fft(out)));
Fout(length(Fout)/2+1:end)=[];
f_ax=linspace(0,0.5,length(Fout));

end