function [out Fout f_ax]=designMaxflat(f0,N,A)

% function [out Fout f_ax]=designMaxflat(f0,N,A)
%
% Design a MAXFLAT lowpass pulse for FDTD simulation: 
%       f0 - Normalized cutoff frequency, (0.5=nyquist)
%       N - Filter order
%       A - Pulse peak amplitude
%
% Returns:
%       out     - Pulse in discrete time domain
%       Fout    - DFT Magnitude of pulse (dB)
%       f_ax    - Frequency axis (normalised) for Fout
%
% Based on:
% J. Sheaffer, M. van Walstijn, and B. M. Fazenda. 
% "Physical and numerical constraints in source modelling for finite 
%   difference simulation of room acoustics."
%
% and: Khan & Ohba, Electronics Letters Vol 36 No 23, 2000.
%
% Code by Jonathan Sheaffer, University of Salford, March 2013
% contact: jon@jonsh.net
%

h=zeros(1,N);
Q=(2*N-1);

for n=-Q:Q
    top=factdbl(Q)^2 * sin(n*2*pi*f0);
    if isodd(n)
        bot=2*n*factdbl(2*N+n-1)*factdbl(2*N-n-1);
    else
        bot=pi*n*factdbl(2*N+n-1)*factdbl(2*N-n-1);
    end
    h(n+Q+1)=top/bot;
end
h(Q+1)=2*f0;

out=A*h/norm(h,inf);
out(end:1024)=0;
Fout=20*log10(abs(fft(out)));
Fout(length(Fout)/2+1:end)=[];
f_ax=linspace(0,0.5,length(Fout));

end

function out=factdbl(in)            % Calculate a double factorial
    out = 1;
    for ii = in:-2:1
        out = out * ii;
    end
end