function [out a1 a2 b0 b2] = designMechSphere(M,f0,Q,T)

% Design a mechanical filter of a small pulsating sphere
%
% function [out a1 a2 b0 b2] = designMechSphere(M,f0,Q,T)
%
% Inputs:
%   M       - Mass of sphere (kg)
%   f0      - Normalised low resonance of mechanical system (0.5=Nyquist)
%   Q       - Q of mechanical system
%   T       - Temporal sample period (s)
%
% Output:
%   out     - Impulse response of pulsating sphere
%   a1, a2, b0, b2 - Coefficients for mechanical filter
%
% Based on:
% J. Sheaffer, M. van Walstijn, and B. M. Fazenda. 
% "Physical and numerical constraints in source modelling for finite 
%   difference simulation of room acoustics."
%
% Code by Jonathan Sheaffer, University of Salford, March 2013
% contact: jon@jonsh.net
%
    h=zeros(1,4096);
    h(10)=1;                        % Time shifted Kronecker delta
    fs=1/T;
    w0 = 2*pi*f0*fs;                % Angular Resonance
    K = M*w0^2;                     % Elasticity
    R = w0*M/Q;                     % Resistance
    beta=w0/tan(w0*T/2);            % Bilinear operator
    b0=beta/(M*beta^2+R*beta+K);    % Transform coefficients
    b2=-b0;
    a1=(2*(K-M*beta^2))/(M*beta^2+R*beta+K);
    a2=1-(2*R*beta/(M*beta^2+R*beta+K));
    num=[b0 0 b2];
    den=[1 a1 a2];
    out=filter(num,den,h);          % Impulse response

end
