function [out Fout f_ax] = designRicker(A,nLen,n0,f0)
% function [out Fout f_ax] = designRicker(A,nLen,n0,f0)
%
% Design a Ricker pulse for FDTD simulation:
%       A       - Pulse amplitude
%       nLen    - Length of pulse (samples)
%       n0      - Time shifting (samples)
%       f0      - Normalised centre frequency (0.5=nyquist)
%
% Returns:
%       out     - Pulse in discrete time domain
%       Fout    - DFT Magnitude of pulse (dB)
%       f_ax    - Frequency axis (normalised) for Fout
%
% Example:
%       [out Fout f_ax] = designRicker(1,1024,50,0.05)
%
% Based on:
% J. Sheaffer, M. van Walstijn, and B. M. Fazenda. 
% "Physical and numerical constraints in source modelling for finite 
%   difference simulation of room acoustics."
%
% Code by Jonathan Sheaffer, University of Salford, March 2013
% contact: jon@jonsh.net
%

n=0:nLen-1;
gam=(pi*f0)^2;
out=(1-2*gam*(n-n0).^2).*exp(-gam*(n-n0).^2);
out=A*out/norm(out,inf);

Fout=20*log10(abs(fft(out)));
Fout(length(Fout)/2+1:end)=[];
f_ax=linspace(0,0.5,length(Fout));

end